@@ -1,7 +1,7 @@
 use strictures;
 
 package WebService::GoogleAPI::Client;
-$WebService::GoogleAPI::Client::VERSION = '0.12';
+$WebService::GoogleAPI::Client::VERSION = '0.13';
 
 # ABSTRACT: Google API Services Client.
 
@@ -316,7 +316,7 @@ WebService::GoogleAPI::Client - Google API Services Client.
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -326,7 +326,7 @@ Access Google API Services Version 1 using an OAUTH2 User Agent
 
     ## assumes gapi.json configuration in working directory with scoped project and user authorization
     
-    my $gapi_client = WebService::GoogleAPI::Client->new( debug => 1, gapi_json => './gapi.json', user=> 'peter@pscott.com.au' );
+    my $gapi_client = WebService::GoogleAPI::Client->new( debug => 1, gapi_json => 'gapi.json', user=> 'peter@pscott.com.au' );
 
 =head2 AUTOMATIC API REQUEST CONSTRUCTION  - SEND EMAL
 
