@@ -1,7 +1,7 @@
 use strictures;
 
 package WebService::GoogleAPI::Client::UserAgent;
-$WebService::GoogleAPI::Client::UserAgent::VERSION = '0.12';
+$WebService::GoogleAPI::Client::UserAgent::VERSION = '0.13';
 
 # ABSTRACT: User Agent wrapper for working with Google APIs
 
@@ -107,9 +107,12 @@ sub validated_api_query
   my $res = $self->start( $self->build_http_transaction( $params ) )->res;
   ## TODO: HANDLE TIMEOUTS AND OTHER ERRORS IF THEY WEREN'T HANDLED BY build_http_transaction
 
+  ## TODO:
+  return Mojo::Message::Response->new unless ref( $res ) eq 'Mojo::Message::Response';
+
   if ( ( $res->code == 401 ) && $self->do_autorefresh )
   {
-    if ( $res->code == 401 )     ## redundant - was there something else in mind ?
+    if ( $res->code == 401 )    ## redundant - was there something else in mind ?
     {
       croak "No user specified, so cant find refresh token and update access_token" unless $self->user;
       carp "401 response - access_token was expired. Attemptimg to update it automatically ..." if $self->debug;
@@ -181,7 +184,7 @@ WebService::GoogleAPI::Client::UserAgent - User Agent wrapper for working with G
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head2 C<header_with_bearer_auth_token>
 
